@@ -162,7 +162,7 @@ class DataStacker:
                  all_flag_bands=False,
                  all_time=False, point=None,
                  mode=MVSelectOpts.DATASETS):
-        if mode != MVSelectOpts.DATASETS or all_time:
+        if mode == MVSelectOpts.EXTENT or all_time:
             # Not returning datasets - use main product only
             queries = [
                 ProductBandQuery.simple_layer_query(
@@ -207,20 +207,27 @@ class DataStacker:
                 if all_time:
                     return result
                 results.append((query, result))
+            elif mode == MVSelectOpts.IDS:
+                if all_time:
+                    return result
+                results.append((query, result))
             else:
                 return result
         return OrderedDict(results)
 
-    def create_zero_filled_flag_bands(self, data, pbq):
-        var = "No data vars in result"
+    def create_nodata_filled_flag_bands(self, data, pbq):
+        var = None
         for var in data.data_vars.variables.keys():
             break
+        if var is None:
+            raise WMSException("Cannot add default flag data as there is no non-flag data available")
         template = getattr(data, var)
-        new_data = numpy.ndarray(template.shape, dtype="uint8")
-        new_data.fill(0)
-        qry_result = template.copy(data=new_data)
         data_new_bands = {}
         for band in pbq.bands:
+            default_value = pbq.products[0].measurements[band].nodata
+            new_data = numpy.ndarray(template.shape, dtype="uint8")
+            new_data.fill(default_value)
+            qry_result = template.copy(data=new_data)
             data_new_bands[band] = qry_result
         data = data.assign(data_new_bands)
         for band in pbq.bands:
@@ -256,7 +263,7 @@ class DataStacker:
                     qry_result["time"] = data.time
                 else:
                     if len(qry_result.time) == 0:
-                        data = self.create_zero_filled_flag_bands(data, pbq)
+                        data = self.create_nodata_filled_flag_bands(data, pbq)
                         continue
                     else:
                         data_new_bands = {}
@@ -272,7 +279,7 @@ class DataStacker:
                     continue
             elif len(qry_result.time) == 0:
                 # Time-aware mask product has no data, but main product does.
-                data = self.create_zero_filled_flag_bands(data, pbq)
+                data = self.create_nodata_filled_flag_bands(data, pbq)
                 continue
             qry_result.coords["time"] = data.coords["time"]
             data = xarray.combine_by_coords([data, qry_result], join="exact")
@@ -421,7 +428,7 @@ def get_map(args):
                 stacker.resource_limited = True
                 qprof["resource_limited"] = str(e)
             if qprof.active:
-                qprof["datasets"] = stacker.datasets(dc.index, mode=MVSelectOpts.IDS)
+                qprof["datasets"] = {str(q): ids for q, ids in stacker.datasets(dc.index, mode=MVSelectOpts.IDS).items()}
             if stacker.resource_limited and not params.product.low_res_product_names:
                 qprof.start_event("extent-in-query")
                 extent = stacker.datasets(dc.index, mode=MVSelectOpts.EXTENT)
@@ -497,7 +504,7 @@ def get_map(args):
                     raise EmptyResponse()
                 else:
                     qprof["write_action"] = "Write Data"
-                    if mdh and  mdh.preserve_user_date_order:
+                    if mdh and mdh.preserve_user_date_order:
                         sorter = user_date_sorter(data.time.values,
                                               params.geobox.geographic_extent,
                                               params.times)
