@@ -315,7 +315,7 @@ def get_coverage_data(req, qprof):
                                                   sum(req.product.band_idx.dtype_size(b) for b in req.bands),
                                                   len(req.times))
         except ResourceLimited as e:
-            if e.wcs_hard or req.product.low_res_product_names is None:
+            if e.wcs_hard or not req.product.low_res_product_names:
                 raise WCS1Exception(
                     f"This request processes too much data to be served in a reasonable amount of time. ({e}) "
                     + "Please reduce the bounds of your request and try again.")
@@ -372,14 +372,15 @@ def get_coverage_data(req, qprof):
         datasets = stacker.datasets(index=dc.index)
         qprof.end_event("fetch-datasets")
         if qprof.active:
-            qprof["datasets"] = stacker.datasets(dc.index, mode=MVSelectOpts.IDS)
+            qprof["datasets"] = {str(q): ids for q, ids in stacker.datasets(dc.index, mode=MVSelectOpts.IDS).items()}
         qprof.start_event("load-data")
         output = stacker.data(datasets, skip_corrections=True)
         qprof.end_event("load-data")
 
         # Clean extent flag band from output
+        sanitised_bands = [req.product.band_idx.locale_band(b) for b in req.bands]
         for k, v in output.data_vars.items():
-            if k not in req.bands:
+            if k not in sanitised_bands:
                 output = output.drop_vars([k])
         qprof["write_action"] = "Write Data"
         return n_datasets, output
