@@ -257,7 +257,7 @@ def get_coverage_data(request, qprof):
                                                   len(times)
                                            )
         except ResourceLimited as e:
-            if e.wcs_hard or layer.low_res_product_names is None:
+            if e.wcs_hard or not layer.low_res_product_names:
                 raise WCS2Exception(
                     f"This request processes too much data to be served in a reasonable amount of time. ({e}) "
                     + "Please reduce the bounds of your request and try again.")
@@ -273,7 +273,7 @@ def get_coverage_data(request, qprof):
         datasets = stacker.datasets(dc.index)
         qprof.end_event("fetch-datasets")
         if qprof.active:
-            qprof["datasets"] = stacker.datasets(dc.index, mode=MVSelectOpts.IDS)
+            qprof["datasets"] = {str(q): ids for q, ids in stacker.datasets(dc.index, mode=MVSelectOpts.IDS).items()}
         if fmt.multi_time and len(times) > 1:
             # Group by solar day
             group_by = datacube.api.query.query_group_by(time=times, group_by='solar_day')
